@@ -1,24 +1,26 @@
 # -*- coding: utf-8 -*-
 '''
-    :codeauthor: :email:`Pedro Algarvio (pedro@algarvio.me)`
-    :copyright: Copyright 2015 by the SaltStack Team, see AUTHORS for more details.
-    :license: Apache 2.0, see LICENSE for more details.
+pytestsalt.fixtures.dirs
+~~~~~~~~~~~~~~~~~~~~~~~~
 
-
-    pytestsalt.fixtures.dirs
-    ~~~~~~~~~~~~~~~~~~~~~~~~
-
-    pytest salt directories related fixtures
+pytest salt directories related fixtures
 '''
 # pylint: disable=redefined-outer-name
 
 # Import Python libs
 from __future__ import absolute_import
 import logging
+import os
+import stat
 
 # Import 3rd-party libs
 import pytest
 
+# Import pytest-salt libs
+import pytestsalt.salt.engines
+import pytestsalt.salt.log_handlers
+
+
 log = logging.getLogger(__name__)
 
 ROOT_DIR = 'root'
@@ -591,6 +593,32 @@ def session_sshd_config_dir(tempdir):
     return config_dir
 
 
+@pytest.fixture
+def sshd_priv_dir():
+    '''
+    Create the privdir for starting sshd on systems that do not have an sshd
+    daemon already running
+    '''
+    if not os.path.isdir('/var/run/sshd'):
+        os.mkdir('/var/run/sshd/')
+        os.chmod('/var/run/sshd/', stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP | stat.S_IROTH | stat.S_IXOTH)
+        yield
+        os.rmdir('/var/run/sshd')
+
+
+@pytest.fixture(scope='session')
+def session_sshd_priv_dir():
+    '''
+    Create the privdir for starting sshd on systems that do not have an sshd
+    daemon already running
+    '''
+    if not os.path.isdir('/var/run/sshd'):
+        os.mkdir('/var/run/sshd/')
+        os.chmod('/var/run/sshd/', stat.S_IRWXU | stat.S_IRGRP | stat.S_IXGRP | stat.S_IROTH | stat.S_IXOTH)
+        yield
+        os.rmdir('/var/run/sshd')
+
+
 @pytest.fixture
 def ssh_config_dir(tempdir):
     '''
@@ -609,3 +637,19 @@ def session_ssh_config_dir(tempdir):
     config_dir = tempdir.join('session-ssh-client')
     config_dir.ensure(dir=True)
     return config_dir
+
+
+@pytest.fixture(scope='session')
+def log_handlers_dir():
+    '''
+    Return the directory name for the pytest-salt log handlers directory
+    '''
+    return os.path.dirname(pytestsalt.salt.log_handlers.__file__)
+
+
+@pytest.fixture(scope='session')
+def engines_dir():
+    '''
+    Return the directory name for the pytest-salt engines directory
+    '''
+    return os.path.dirname(pytestsalt.salt.engines.__file__)
